/*
 * File         : BV_AudioPlay.C
 * Author       : Tomasz Stachowiak
 * Created      : Fri Jul 24 15:11:05 1998
 * Revision     : $Revision$
 * Updated      : $Date$
 * Copyright: Northeast Parallel Architectures Center
 *            at Syracuse University 1998
 */

#include <stdio.h>
#include <dmedia/audio.h>

#include "BV_AudioPlay.h"

int BV_AudioPlay::init()
{
  return set_rate(DEFAULT_RATE);
  
}

int BV_AudioPlay::set_rate(long rate)
{
  long buf[2];
  
  buf[0] = AL_OUTPUT_RATE;
  buf[1] = rate;
  
  ALsetparams(AL_DEFAULT_DEVICE, buf, 2);

  return 0;
}

int BV_AudioPlay::set_volume(long volume)
{
  long buf[4];
  
  buf[0] = AL_LEFT_SPEAKER_GAIN;
  buf[2] = AL_RIGHT_SPEAKER_GAIN;
  buf[1] = volume;
  buf[3] = volume;
  ALsetparams(AL_DEFAULT_DEVICE, buf, 4);

  return 0;
}

long BV_AudioPlay::get_volume()
{
  long buf[4];
  
  buf[0] = AL_LEFT_SPEAKER_GAIN;
  buf[2] = AL_RIGHT_SPEAKER_GAIN;
  
  ALgetparams(AL_DEFAULT_DEVICE, buf, 4);

  return (buf[1] + buf[3])/2;
}

int BV_AudioPlay::open()
{
  if ((conf = ALnewconfig()) == 0)
    {
      fprintf (stderr, "Config allocation error\n");
      return -1;
    }

  if (ALsetchannels(conf, MONO) < 0)
    {
      fprintf (stderr, "Setting channel error\n");
      return -1;
    }
  if (ALsetqueuesize(conf, QSIZE) < 0)
    {
      fprintf (stderr, "Setting queue size error\n");
      return -1;
    }
  if (ALsetwidth(conf, AL_SAMPLE_16) < 0)
    {
      fprintf (stderr, "Setting sample width error\n");
      return -1;
    }

  port = ALopenport("speaker", "w", conf);
  if(port == NULL)
    return -1;

  return 0;
}

void BV_AudioPlay::close()
{
  if(port != NULL)
    ALcloseport(port);
}

int BV_AudioPlay::play(char *buffer, int size)
{
  ALwritesamps(port, buffer, size);
  return 0;
}
